@@ -4,22 +4,16 @@
 #' @param \dots Extra arguments. Currently unused.
 #'
 #'  @exportS3Method coef semtree
-#' 
-coef.semtree <- function(object, ...)
-{
+#'
+coef.semtree <- function(object, ...) {
   model <- object$model
-  
+
   if (inherits(model, "MxModel") || inherits(model, "MxRAMModel")) {
-  	
     return(omxGetParameters(model))
-    
   } else if (inherits(model, "lavaan")) {
-    
     return(lavaan::coef(model))
-    
   } else {
     warning("Model class is not supported!")
     return(NULL)
   }
-  
-}
\ No newline at end of file
+}
