@@ -386,13 +386,15 @@ growTree <- function(model = NULL, mydata = NULL,
     ui_ok("Best split is  ", result$name.max, " with statistic = ", round(node$lr, 2))
   }
 
-  # compute p value from chi2
+  # compute p value from chi2 unless the p value
+  # was already provided
   if (!is.null(result$p.max)) {
     node$p <- result$p.max
   } else {
+    
     node$p <- pchisq(node$lr, df = node$df, lower.tail = F)
 
-    if (control$use.maxlm) {
+    if (isTRUE(control$use.maxlr)) {
       # Borders for continuous covariates
       if (!is.factor(mydata[, result$name.max])) {
         props <- cumsum(table(mydata[, result$name.max])) / node$N
@@ -429,9 +431,28 @@ growTree <- function(model = NULL, mydata = NULL,
       )
     }
   }
-
+  
+  
+  #   # Multiple-Testing Correction is hidden here
+  if (node$p.values.valid) {
+  if (control$bonferroni && !is.null(result$n.comp)) {
+    node$p.uncorrected <- node$p
+    # this is less accurate, but numerically more stable
+    node$p <- min(1, node$p * result$n.comp)
+    node$p.numtests <- result$n.comp
+    
+  }
+  
+  if (control$report.level > 5) {
+    report(paste("Stopping rule applied based on p value ",node$p), 1)
+    if (control$bonferroni) {
+      report(paste("Uncorrected p value was ",node$p.uncorrected), 2)       
+    }
+  }
+  }
 
   # ---------	determine whether to continue splitting	--------------
+
   if (is(control$custom.stopping.rule, "function")) {
     stopping.rule <- control$custom.stopping.rule
   } else {
@@ -530,7 +551,7 @@ growTree <- function(model = NULL, mydata = NULL,
       # the best column in the matrix that represents all subsets
       # make sure that this is not casted to a string if there
       # are predictors of other types (esp., factors)
-      # browser()
+
       if (!all(is.na(result$btn.matrix))) {
         result$split.max <- as.integer(result$split.max)
 
@@ -617,6 +638,7 @@ growTree <- function(model = NULL, mydata = NULL,
         formula = as.formula(paste0(result$name.max, "~."))
       )
     }
+    
 
 
     # recursively continue splitting
